#!/usr/bin/env cwl-runner

cwlVersion: v1.2
class: Workflow

requirements:
  InlineJavascriptRequirement: {}
  ScatterFeatureRequirement: {}
  StepInputExpressionRequirement: {}
  MultipleInputFeatureRequirement: {}

inputs:
  arvados_input_collection_locators: string[]
  arvados_output_collection_name: string
  arvados_api_host: string
  arvados_api_token: string

outputs:
  hap_files:
    type: File[]
    outputSource: bcftools_convert/bcftools_hap_out
  sample_files:
    type: File[]
    outputSource: bcftools_convert/bcftools_sample_out
  arvados_output_collection_locator:
    type: string
    outputSource: arv_put/collection_locator

steps:
  arv_get:
    run: arv-get.cwl
    scatter: arvados_collection_locator
    in:
      arvados_api_token: arvados_api_token
      arvados_api_host: arvados_api_host
      arvados_collection_locator: arvados_input_collection_locators
      arvados_destination_file:
        valueFrom: $(inputs.arvados_collection_locator.split('/')[1])
    out: [collection_file]

  bcftools_convert:
    run: bcftools-convert-vcf2hapsample.cwl
    scatter: vcf_file
    in:
      hap_sample_file_prefix:
        valueFrom: $( inputs.vcf_file.basename.slice(0, -7) )
      vcf_file: arv_get/collection_file
    out: [bcftools_hap_out, bcftools_sample_out]

  arv_put:
    run: arv-put.cwl
    in:
      arvados_api_token: arvados_api_token
      arvados_api_host: arvados_api_host
      arvados_files:
        source:
          - bcftools_convert/bcftools_sample_out
          - bcftools_convert/bcftools_hap_out
        linkMerge: merge_flattened
      arvados_collection_name: arvados_output_collection_name
    out: [collection_locator]
